==> franchise_service-tomato.20190105.110047-5-sources.jar: com/jz/jar/franchise/service/StudentSchoolContractService.java <==
package com.jz.jar.franchise.service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.tuple.Pair;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.franchise.repository.StudentSchoolContractRepository;
import com.jz.jooq.franchise.tables.pojos.StudentSchoolContract;

@Lazy
@Service
public class StudentSchoolContractService {

	@Autowired
	private StudentSchoolContractRepository studentSchoolContractRepository;

	public Pair<Integer, Integer> getLessionCount(String suid) {
		return studentSchoolContractRepository.getLessionCount(suid);
	}

	public Map<String, Pair<Integer, Integer>> getLessionCount(Collection<String> suids) {
		return studentSchoolContractRepository.getLessionCount(suids);
	}

	/** 获取当前合同已经请假的天数 */
	public List<StudentSchoolContract> getStudentSchoolContracts(String suid,
			Map<String, Collection<String>> school2ContractId) {
		return studentSchoolContractRepository.getStudentSchoolContracts(suid, school2ContractId);
	}

	public StudentSchoolContract getStudentSchoolContract(String suid, String school, String contractId) {
		return studentSchoolContractRepository.getStudentSchoolContract(suid, school, contractId);
	}

	public void addLeaveNum(String suid, String school, String contractId, int addCnt) {
		studentSchoolContractRepository.addLeaveNum(suid, school, contractId, addCnt);
	}
}

==> franchise_service-tomato.20190119.060710-49-sources.jar: com/jz/jar/franchise/service/StudentSchoolContractService.java <==
package com.jz.jar.franchise.service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.tuple.Pair;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.franchise.repository.StudentSchoolContractRepository;
import com.jz.jooq.franchise.tables.pojos.StudentSchoolContract;

@Lazy
@Service
public class StudentSchoolContractService {

	@Autowired
	private StudentSchoolContractRepository studentSchoolContractRepository;

	public Pair<Integer, Integer> getLessionCount(String suid) {
		return studentSchoolContractRepository.getLessionCount(suid);
	}

	public Map<String, Pair<Integer, Integer>> getLessionCount(Collection<String> suids) {
		return studentSchoolContractRepository.getLessionCount(suids);
	}

	/** 获取当前合同已经请假的天数 */
	public List<StudentSchoolContract> getSimpleStudentSchoolContracts(String suid,
			Map<String, Collection<String>> school2ContractId) {
		return studentSchoolContractRepository.getSimpleStudentSchoolContracts(suid, school2ContractId);
	}

	public StudentSchoolContract getStudentSchoolContract(String suid, String school, String contractId) {
		return studentSchoolContractRepository.getStudentSchoolContract(suid, school, contractId);
	}

	public void addLeaveNum(String suid, String school, String contractId, int addCnt) {
		studentSchoolContractRepository.addLeaveNum(suid, school, contractId, addCnt);
	}
}
